@@ -7,9 +7,16 @@ import { EventEmitter } from 'events';
 import * as dbg from 'debug';
 import * as machina from 'machina';
 import * as async from 'async';
-
-import { anHourFromNow, errors, results, SharedAccessSignature, Message, callbackToPromise, tripleValueCallbackToPromise, Callback, endpoint } from 'azure-iot-common';
-import { Amqp as Base, AmqpMessage, SenderLink, AmqpBaseTransportConfig } from 'azure-iot-amqp-base';
+import * as endpoint from './common-core/endpoint';
+import { anHourFromNow } from './common-core/authorization';
+import { SharedAccessSignature } from './common-core/shared_access_signature';
+import { Message } from './common-core/message';
+import { callbackToPromise, tripleValueCallbackToPromise, Callback } from './common-core/promise_utils';
+import * as errors from './common-core/errors';
+import * as results from './common-core/results';
+import { Amqp as Base, AmqpBaseTransportConfig } from './common-amqp/amqp';
+import { AmqpMessage } from './common-amqp/amqp_message';
+import { SenderLink } from './common-amqp/sender_link';
 import { translateError } from './amqp_service_errors.js';
 import { Client } from './client';
 import { ServiceReceiver } from './service_receiver.js';
