@@ -196,6 +196,7 @@ export class IoTHubRegistryManager {
 
   /**
    * Constructor which also creates an instance of the Protocol Layer Client used by the DigitalTwinClient.
+   *
    * @param {IoTHubTokenCredentials} creds    The IoTHub token credentials used for creating the Protocol Layer client.
    * @memberof DigitalTwinClient
    */
@@ -268,7 +269,7 @@ export class IoTHubRegistryManager {
     deviceId: string,
     primaryThumbprint: string,
     secondaryThumbprint: string,
-    isEnabled: Boolean,
+    isEnabled: boolean,
     iotEdge: boolean = false
   ): Promise<DevicesCreateOrUpdateIdentityResponse> {
     const x509Thumbprint: X509Thumbprint = {
